Module: Mesa
Branch: main
Commit: 70f193ffcf39124b975a912a0c80f6de3b6b1976
URL:    
http://cgit.freedesktop.org/mesa/mesa/commit/?id=70f193ffcf39124b975a912a0c80f6de3b6b1976

Author: Tapani Pälli <[email protected]>
Date:   Thu Oct  7 08:27:09 2021 +0300

intel/isl: FXT1 support was removed on Gfx12.5

v2: cleanup (Jordan Justen)

Signed-off-by: Tapani Pälli <[email protected]>
Reviewed-by: Adam Jackson <[email protected]>
Reviewed-by: Jason Ekstrand <[email protected]>
Reviewed-by: Jordan Justen <[email protected]>
Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/13241>

---

 src/intel/isl/isl_format.c | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/src/intel/isl/isl_format.c b/src/intel/isl/isl_format.c
index de2b5eaaf9d..321b857719a 100644
--- a/src/intel/isl/isl_format.c
+++ b/src/intel/isl/isl_format.c
@@ -735,13 +735,14 @@ isl_format_supports_sampling(const struct 
intel_device_info *devinfo,
          return true;
    } else if (devinfo->verx10 >= 125) {
       const struct isl_format_layout *fmtl = isl_format_get_layout(format);
       /* ASTC support was removed from the hardware on Gfx12.5.  Annoyingly,
        * our format_info table doesn't have a concept of things being removed
        * so we handle it as yet another special case.
        *
-       * See HSD 1408144932
        */
-      if (fmtl->txc == ISL_TXC_ASTC)
+      if (fmtl->txc == ISL_TXC_ASTC || fmtl->txc == ISL_TXC_FXT1)
          return false;
    }
 
@@ -735,13 +735,14 @@ isl_format_supports_sampling(const struct 
    } else if (devinfo->verx10 >= 125) {
       const struct isl_format_layout *fmtl = isl_format_get_layout(format);
-      /* ASTC support was removed from the hardware on Gfx12.5.  Annoyingly,
-       * our format_info table doesn't have a concept of things being removed
-       * so we handle it as yet another special case.
+      /* ASTC & FXT1 support was removed from the hardware on Gfx12.5.
+       * Annoyingly, our format_info table doesn't have a concept of things
+       * being removed so we handle it as yet another special case.
+       *
+       * See HSD 1408144932 (ASTC), 1407633611 (FXT1)
        *

Reply via email to